//////////////////////////////// Includes /////////////////////////////////////

#include "stdafx.h"
#include "YKUSHWrappers.h"


//////////////////////////////// Implementation ///////////////////////////////

int _tmain()
{
  _tprintf(_T("Enumerating YEPKIT YKUSH XS devices on this computer\n"));
  HID::StringArray deviceNames;
  bool bSuccess = HID::CYKUSHXSDevice::Enumerate(deviceNames); //NOLINT(clang-analyzer-deadcode.DeadStores)
#pragma warning(suppress: 26477)
  ATLASSERT(bSuccess);
  HID::String sDevicePath;
  for (const auto& device : deviceNames)
  {
    _tprintf(_T(" Found device path of %s\n"), device.c_str());
    sDevicePath = device;
  }
  if (sDevicePath.length() == 0)
  {
    _tprintf(_T(" No YEPKIT YKUSH XS devices found\n"));
    return 1;
  }

  //Open up the HID temper device
  HID::CYKUSHXSDevice device;
  bSuccess = device.Open(sDevicePath.c_str()); //NOLINT(clang-analyzer-deadcode.DeadStores)
#pragma warning(suppress: 26477)
  ATLASSERT(bSuccess);

  //Display some various info about device
  std::vector<wchar_t> wszProduct;
  wszProduct.resize(127);
#pragma warning(suppress: 26472)
  if (device.GetProductString(wszProduct.data(), static_cast<ULONG>(wszProduct.size())))
    _tprintf(_T("Product: %ws\n"), wszProduct.data());
  std::vector<wchar_t> wszManufacturer;
  wszManufacturer.resize(127);
#pragma warning(suppress: 26472)
  if (device.GetManufacturerString(wszManufacturer.data(), static_cast<ULONG>(wszManufacturer.size())))
    _tprintf(_T("Manufacturer: %ws\n"), wszManufacturer.data());
  std::vector<wchar_t> wszSerialNumber;
  wszSerialNumber.resize(127);
#pragma warning(suppress: 26472)
  if (device.GetSerialNumberString(wszSerialNumber.data(), static_cast<ULONG>(wszSerialNumber.size())))
    _tprintf(_T("Serial Number: %ws\n"), wszSerialNumber.data());

  BYTE byStatus = 0x0;
  if (device.PortStatus(byStatus))
  {
    _tprintf(_T("Downstream port status: 0x%X\n"), static_cast<int>(byStatus));
    if (byStatus == 0x11)
      _tprintf(_T("Downstream port is ON\n"));
    else
      _tprintf(_T("Downstream port is OFF\n"));
  }
  else
    _tprintf(_T("Failed to get downstream port status, Error:%u\n"), GetLastError()); //NOLINT(clang-diagnostic-format)

  if (device.PortUp())
    _tprintf(_T("Downstream port is now ON\n"));
  else
    _tprintf(_T("Failed to turn on downstream port, Error:%u\n"), GetLastError()); //NOLINT(clang-diagnostic-format)

  if (device.PortDown())
    _tprintf(_T("Downstream port is now OFF\n"));
  else
    _tprintf(_T("Failed to turn of downstream port, Error:%u\n"), GetLastError()); //NOLINT(clang-diagnostic-format)

  return 0;
}
